@@ -7,22 +7,20 @@ use Moo;
 
 use Carp qw/ croak /;
 use Devel::StrictMode;
-use File::ShareDir qw/ module_file /;
+use File::ShareDir 1.112 qw/ module_file /;
 use MooX::TypeTiny;
-use List::Util qw/ first uniqstr /;
+use List::Util 1.45 qw/ first uniqstr /;
 use Path::Tiny;
 use Types::Path::Tiny qw/ Dir File Path /;
 use Types::Common::Numeric qw/ PositiveOrZeroInt /;
 use Types::Common::String qw/ NonEmptySimpleStr SimpleStr /;
 use Types::Standard qw/ Bool CodeRef HashRef Maybe Tuple /;
-use Types::URI qw/ Uri /;
-use URI;
 
 # RECOMMEND PREREQ: Type::Tiny::XS
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.1.2';
 
 
 
@@ -58,7 +56,7 @@ has prefer_min => (
 has css_files => (
     is  => 'lazy',
     isa => STRICT
-             ? HashRef [ Tuple [ Maybe[Path], Path | Uri, PositiveOrZeroInt ] ]
+             ? HashRef [ Tuple [ Maybe[Path], NonEmptySimpleStr, PositiveOrZeroInt ] ]
              : HashRef,
     builder => 1,
     coerce  => 1,
@@ -78,7 +76,7 @@ sub _build_css_files {
     for my $name (keys %{ $self->aliases }) {
         my $base  = $self->aliases->{$name};
         if ($base =~ m{^(\w+:)?//}) {
-            $files{$name} = [ undef, URI->new($base), 0 ];
+            $files{$name} = [ undef, $base, 0 ];
         }
         else {
             my @bases = ( $base );
@@ -89,7 +87,7 @@ sub _build_css_files {
                 croak "alias '$name' refers to a non-existent file";
             }
             # PATH NAME SIZE
-            $files{$name} = [ $file, $file->relative($root), $file->stat->size ];
+            $files{$name} = [ $file, $file->relative($root)->stringify, $file->stat->size ];
         }
     }
 
@@ -172,7 +170,7 @@ sub href {
     $file //= $self->css_files->{$name};
     croak "invalid name '$name'" unless defined $file;
     if (defined $file->[PATH]) {
-        my $href = $self->url_base_path . $file->[NAME]->stringify;
+        my $href = $self->url_base_path . $file->[NAME];
         $href .= '?' . $self->asset_id if $self->has_asset_id;
         if ($self->use_cdn_links && $self->has_cdn_links) {
             return $self->cdn_links->{$name} // $href;
@@ -268,7 +266,7 @@ HTML::DeferableCSS - Simplify management of stylesheets in your HTML
 
 =head1 VERSION
 
-version v0.1.1
+version v0.1.2
 
 =head1 SYNOPSIS
 
@@ -293,7 +291,20 @@ version v0.1.1
 
 =head1 DESCRIPTION
 
-This is an experimental module.
+This is an experimental module for generating HTML-snippets for
+deferable stylesheets.
+
+This allows the stylesheets to be loaded asynchronously, allowing the
+page to be rendered faster.
+
+Ideally, this would be a simple matter of changing stylesheet links
+to something like
+
+  <link rel="preload" as="stylesheet" href="....">
+
+but this is not well supported by all web browsers. So a web page
+needs some JavaScript to handle this, as well as a C<noscript> block
+as a fallback.
 
 This module allows you to simplify the management of stylesheets for a
 web application, from development to production by
@@ -471,7 +482,7 @@ if the file size is not greater than L</inline_max>.
   my $html = $css->deferred_link_html( @aliases );
 
 This returns the HTML markup for the stylesheets specified by
-L<@aliases>, as appropriate for each stylesheet.
+L</aliases>, as appropriate for each stylesheet.
 
 If the stylesheets are not greater than L</inline_max>, then it will
 embed them.  Otherwise it will return the appropriate markup,
@@ -494,6 +505,10 @@ All files are embedded as raw files.
 
 No URL encoding is done on the HTML links or L</asset_id>.
 
+=head2 It's spelled "Deferrable"
+
+It's also spelled "Deferable".
+
 =head1 SOURCE
 
 The development version is on github at L<https://github.com/robrwo/HTML-DeferableCSS>
